OOKNET                             [ /  search the index  ]  
──────────────────────────────────────────────────────────────────────────────────────
══════════════════════════════════════════════════════════════════════════════════════
OOKNET   [ /  search  ]  
────────────────────────────────────────────────
════════════════════════════════════════════════
 
HASH      f7bbb3f30440
DATE      2025-09-10
SUBJECT   nix: period 1027
FILES     1 CHANGED
HASH      f7bbb3f30440
DATE      2025-09-10
SUBJECT   nix: period 1027
FILES     1 CHANGED
 

diff --git a/nix/apps/challenge-mode-leaderboard.nix b/nix/apps/challenge-mode-lea
derboard.nix
index f494fa5..28756db 100644
--- a/nix/apps/challenge-mode-leaderboard.nix
+++ b/nix/apps/challenge-mode-leaderboard.nix
@@ -32,8 +32,8 @@
 
       def get_hardcoded_period_and_dungeons():
           # hardcoded values since the index endpoint is broken
-          # all records are now in period 1026
-          period_id = "1026"
+          # all records are now in period 1027
+          period_id = "1027"
 
           dungeons = [
               {"id": 2, "name": "Temple of the Jade Serpent", "slug": "temple-of-
the-jade-serpent"},

diff --git a/nix/apps/challenge-mode-leaderb
oard.nix b/nix/apps/challenge-mode-leaderboa
rd.nix
index f494fa5..28756db 100644
--- a/nix/apps/challenge-mode-leaderboard.ni
x
+++ b/nix/apps/challenge-mode-leaderboard.ni
x
@@ -32,8 +32,8 @@
 
       def get_hardcoded_period_and_dungeons
():
           # hardcoded values since the inde
x endpoint is broken
-          # all records are now in period 1
026
-          period_id = "1026"
+          # all records are now in period 1
027
+          period_id = "1027"
 
           dungeons = [
               {"id": 2, "name": "Temple of 
the Jade Serpent", "slug": "temple-of-the-ja
de-serpent"},
 
[ BACK TO LOG ]
──────────────────────────────────────────────────────────────────────────────────────
OOKNET
────────────────────────────────────────────────
OOKNET